==> openshift-model-machineconfig-5.10.1-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/KubeletConfigSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.openshift.api.model.TLSSecurityProfile;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class KubeletConfigSpecFluentImpl<A extends io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluent<A>{
  public KubeletConfigSpecFluentImpl() {
  }
  public KubeletConfigSpecFluentImpl(io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpec instance) {
    this.withAutoSizingReserved(instance.getAutoSizingReserved()); 
    this.withKubeletConfig(instance.getKubeletConfig()); 
    this.withLogLevel(instance.getLogLevel()); 
    this.withMachineConfigPoolSelector(instance.getMachineConfigPoolSelector()); 
    this.withTlsSecurityProfile(instance.getTlsSecurityProfile()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean autoSizingReserved;
  private java.util.Map<java.lang.String,java.lang.Object> kubeletConfig;
  private java.lang.Integer logLevel;
  private io.fabric8.kubernetes.api.model.LabelSelectorBuilder machineConfigPoolSelector;
  private io.fabric8.openshift.api.model.TLSSecurityProfile tlsSecurityProfile;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getAutoSizingReserved() {
    return this.autoSizingReserved;
  }
  public A withAutoSizingReserved(java.lang.Boolean autoSizingReserved) {
    this.autoSizingReserved=autoSizingReserved; return (A) this;
  }
  public java.lang.Boolean hasAutoSizingReserved() {
    return this.autoSizingReserved != null;
  }
  public A addToKubeletConfig(java.lang.String key,java.lang.Object value) {
    if(this.kubeletConfig == null && key != null && value != null) { this.kubeletConfig = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.kubeletConfig.put(key, value);} return (A)this;
  }
  public A addToKubeletConfig(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.kubeletConfig == null && map != null) { this.kubeletConfig = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.kubeletConfig.putAll(map);} return (A)this;
  }
  public A removeFromKubeletConfig(java.lang.String key) {
    if(this.kubeletConfig == null) { return (A) this; }
    if(key != null && this.kubeletConfig != null) {this.kubeletConfig.remove(key);} return (A)this;
  }
  public A removeFromKubeletConfig(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.kubeletConfig == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.kubeletConfig != null){this.kubeletConfig.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getKubeletConfig() {
    return this.kubeletConfig;
  }
  public <K,V>A withKubeletConfig(java.util.Map<java.lang.String,java.lang.Object> kubeletConfig) {
    if (kubeletConfig == null) { this.kubeletConfig =  null;} else {this.kubeletConfig = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(kubeletConfig);} return (A) this;
  }
  public java.lang.Boolean hasKubeletConfig() {
    return this.kubeletConfig != null;
  }
  public java.lang.Integer getLogLevel() {
    return this.logLevel;
  }
  public A withLogLevel(java.lang.Integer logLevel) {
    this.logLevel=logLevel; return (A) this;
  }
  public java.lang.Boolean hasLogLevel() {
    return this.logLevel != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMachineConfigPoolSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getMachineConfigPoolSelector() {
    return this.machineConfigPoolSelector!=null?this.machineConfigPoolSelector.build():null;
  }
  public io.fabric8.kubernetes.api.model.LabelSelector buildMachineConfigPoolSelector() {
    return this.machineConfigPoolSelector!=null?this.machineConfigPoolSelector.build():null;
  }
  public A withMachineConfigPoolSelector(io.fabric8.kubernetes.api.model.LabelSelector machineConfigPoolSelector) {
    _visitables.get("machineConfigPoolSelector").remove(this.machineConfigPoolSelector);
    if (machineConfigPoolSelector!=null){ this.machineConfigPoolSelector= new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(machineConfigPoolSelector); _visitables.get("machineConfigPoolSelector").add(this.machineConfigPoolSelector);} return (A) this;
  }
  public java.lang.Boolean hasMachineConfigPoolSelector() {
    return this.machineConfigPoolSelector != null;
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluent.MachineConfigPoolSelectorNested<A> withNewMachineConfigPoolSelector() {
    return new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluentImpl.MachineConfigPoolSelectorNestedImpl();
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluent.MachineConfigPoolSelectorNested<A> withNewMachineConfigPoolSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluentImpl.MachineConfigPoolSelectorNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluent.MachineConfigPoolSelectorNested<A> editMachineConfigPoolSelector() {
    return withNewMachineConfigPoolSelectorLike(getMachineConfigPoolSelector());
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluent.MachineConfigPoolSelectorNested<A> editOrNewMachineConfigPoolSelector() {
    return withNewMachineConfigPoolSelectorLike(getMachineConfigPoolSelector() != null ? getMachineConfigPoolSelector(): new io.fabric8.kubernetes.api.model.LabelSelectorBuilder().build());
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluent.MachineConfigPoolSelectorNested<A> editOrNewMachineConfigPoolSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return withNewMachineConfigPoolSelectorLike(getMachineConfigPoolSelector() != null ? getMachineConfigPoolSelector(): item);
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfile getTlsSecurityProfile() {
    return this.tlsSecurityProfile;
  }
  public A withTlsSecurityProfile(io.fabric8.openshift.api.model.TLSSecurityProfile tlsSecurityProfile) {
    this.tlsSecurityProfile=tlsSecurityProfile; return (A) this;
  }
  public java.lang.Boolean hasTlsSecurityProfile() {
    return this.tlsSecurityProfile != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    KubeletConfigSpecFluentImpl that = (KubeletConfigSpecFluentImpl) o;
    if (autoSizingReserved != null ? !autoSizingReserved.equals(that.autoSizingReserved) :that.autoSizingReserved != null) return false;
    if (kubeletConfig != null ? !kubeletConfig.equals(that.kubeletConfig) :that.kubeletConfig != null) return false;
    if (logLevel != null ? !logLevel.equals(that.logLevel) :that.logLevel != null) return false;
    if (machineConfigPoolSelector != null ? !machineConfigPoolSelector.equals(that.machineConfigPoolSelector) :that.machineConfigPoolSelector != null) return false;
    if (tlsSecurityProfile != null ? !tlsSecurityProfile.equals(that.tlsSecurityProfile) :that.tlsSecurityProfile != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(autoSizingReserved,  kubeletConfig,  logLevel,  machineConfigPoolSelector,  tlsSecurityProfile,  additionalProperties,  super.hashCode());
  }
  public class MachineConfigPoolSelectorNestedImpl<N> extends io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluent.MachineConfigPoolSelectorNested<N>> implements io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluent.MachineConfigPoolSelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MachineConfigPoolSelectorNestedImpl(io.fabric8.kubernetes.api.model.LabelSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this, item);
    }
    MachineConfigPoolSelectorNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LabelSelectorBuilder builder;
    public N and() {
      return (N) KubeletConfigSpecFluentImpl.this.withMachineConfigPoolSelector(builder.build());
    }
    public N endMachineConfigPoolSelector() {
      return and();
    }
    
  }
  
}

==> openshift-model-machineconfig-5.12.2-sources.jar: io/fabric8/openshift/api/model/machineconfig/v1/KubeletConfigSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.machineconfig.v1;

import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.openshift.api.model.TLSSecurityProfile;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class KubeletConfigSpecFluentImpl<A extends io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluent<A>{
  public KubeletConfigSpecFluentImpl() {
  }
  public KubeletConfigSpecFluentImpl(io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpec instance) {
    this.withAutoSizingReserved(instance.getAutoSizingReserved()); 
    this.withKubeletConfig(instance.getKubeletConfig()); 
    this.withLogLevel(instance.getLogLevel()); 
    this.withMachineConfigPoolSelector(instance.getMachineConfigPoolSelector()); 
    this.withTlsSecurityProfile(instance.getTlsSecurityProfile()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean autoSizingReserved;
  private java.util.Map<java.lang.String,java.lang.Object> kubeletConfig;
  private java.lang.Integer logLevel;
  private io.fabric8.kubernetes.api.model.LabelSelectorBuilder machineConfigPoolSelector;
  private io.fabric8.openshift.api.model.TLSSecurityProfile tlsSecurityProfile;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getAutoSizingReserved() {
    return this.autoSizingReserved;
  }
  public A withAutoSizingReserved(java.lang.Boolean autoSizingReserved) {
    this.autoSizingReserved=autoSizingReserved; return (A) this;
  }
  public java.lang.Boolean hasAutoSizingReserved() {
    return this.autoSizingReserved != null;
  }
  public A addToKubeletConfig(java.lang.String key,java.lang.Object value) {
    if(this.kubeletConfig == null && key != null && value != null) { this.kubeletConfig = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.kubeletConfig.put(key, value);} return (A)this;
  }
  public A addToKubeletConfig(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.kubeletConfig == null && map != null) { this.kubeletConfig = new java.util.LinkedHashMap(); }
    if(map != null) { this.kubeletConfig.putAll(map);} return (A)this;
  }
  public A removeFromKubeletConfig(java.lang.String key) {
    if(this.kubeletConfig == null) { return (A) this; }
    if(key != null && this.kubeletConfig != null) {this.kubeletConfig.remove(key);} return (A)this;
  }
  public A removeFromKubeletConfig(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.kubeletConfig == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.kubeletConfig != null){this.kubeletConfig.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getKubeletConfig() {
    return this.kubeletConfig;
  }
  public <K,V>A withKubeletConfig(java.util.Map<java.lang.String,java.lang.Object> kubeletConfig) {
    if (kubeletConfig == null) { this.kubeletConfig =  null;} else {this.kubeletConfig = new java.util.LinkedHashMap(kubeletConfig);} return (A) this;
  }
  public java.lang.Boolean hasKubeletConfig() {
    return this.kubeletConfig != null;
  }
  public java.lang.Integer getLogLevel() {
    return this.logLevel;
  }
  public A withLogLevel(java.lang.Integer logLevel) {
    this.logLevel=logLevel; return (A) this;
  }
  public java.lang.Boolean hasLogLevel() {
    return this.logLevel != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMachineConfigPoolSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getMachineConfigPoolSelector() {
    return this.machineConfigPoolSelector!=null?this.machineConfigPoolSelector.build():null;
  }
  public io.fabric8.kubernetes.api.model.LabelSelector buildMachineConfigPoolSelector() {
    return this.machineConfigPoolSelector!=null?this.machineConfigPoolSelector.build():null;
  }
  public A withMachineConfigPoolSelector(io.fabric8.kubernetes.api.model.LabelSelector machineConfigPoolSelector) {
    _visitables.get("machineConfigPoolSelector").remove(this.machineConfigPoolSelector);
    if (machineConfigPoolSelector!=null){ this.machineConfigPoolSelector= new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(machineConfigPoolSelector); _visitables.get("machineConfigPoolSelector").add(this.machineConfigPoolSelector);} return (A) this;
  }
  public java.lang.Boolean hasMachineConfigPoolSelector() {
    return this.machineConfigPoolSelector != null;
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluent.MachineConfigPoolSelectorNested<A> withNewMachineConfigPoolSelector() {
    return new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluentImpl.MachineConfigPoolSelectorNestedImpl();
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluent.MachineConfigPoolSelectorNested<A> withNewMachineConfigPoolSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return new io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluentImpl.MachineConfigPoolSelectorNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluent.MachineConfigPoolSelectorNested<A> editMachineConfigPoolSelector() {
    return withNewMachineConfigPoolSelectorLike(getMachineConfigPoolSelector());
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluent.MachineConfigPoolSelectorNested<A> editOrNewMachineConfigPoolSelector() {
    return withNewMachineConfigPoolSelectorLike(getMachineConfigPoolSelector() != null ? getMachineConfigPoolSelector(): new io.fabric8.kubernetes.api.model.LabelSelectorBuilder().build());
  }
  public io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluent.MachineConfigPoolSelectorNested<A> editOrNewMachineConfigPoolSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item) {
    return withNewMachineConfigPoolSelectorLike(getMachineConfigPoolSelector() != null ? getMachineConfigPoolSelector(): item);
  }
  public io.fabric8.openshift.api.model.TLSSecurityProfile getTlsSecurityProfile() {
    return this.tlsSecurityProfile;
  }
  public A withTlsSecurityProfile(io.fabric8.openshift.api.model.TLSSecurityProfile tlsSecurityProfile) {
    this.tlsSecurityProfile=tlsSecurityProfile; return (A) this;
  }
  public java.lang.Boolean hasTlsSecurityProfile() {
    return this.tlsSecurityProfile != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    KubeletConfigSpecFluentImpl that = (KubeletConfigSpecFluentImpl) o;
    if (autoSizingReserved != null ? !autoSizingReserved.equals(that.autoSizingReserved) :that.autoSizingReserved != null) return false;
    if (kubeletConfig != null ? !kubeletConfig.equals(that.kubeletConfig) :that.kubeletConfig != null) return false;
    if (logLevel != null ? !logLevel.equals(that.logLevel) :that.logLevel != null) return false;
    if (machineConfigPoolSelector != null ? !machineConfigPoolSelector.equals(that.machineConfigPoolSelector) :that.machineConfigPoolSelector != null) return false;
    if (tlsSecurityProfile != null ? !tlsSecurityProfile.equals(that.tlsSecurityProfile) :that.tlsSecurityProfile != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(autoSizingReserved,  kubeletConfig,  logLevel,  machineConfigPoolSelector,  tlsSecurityProfile,  additionalProperties,  super.hashCode());
  }
  public class MachineConfigPoolSelectorNestedImpl<N> extends io.fabric8.kubernetes.api.model.LabelSelectorFluentImpl<io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluent.MachineConfigPoolSelectorNested<N>> implements io.fabric8.openshift.api.model.machineconfig.v1.KubeletConfigSpecFluent.MachineConfigPoolSelectorNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    MachineConfigPoolSelectorNestedImpl(io.fabric8.kubernetes.api.model.LabelSelector item) {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this, item);
    }
    MachineConfigPoolSelectorNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.LabelSelectorBuilder(this);
    }
    io.fabric8.kubernetes.api.model.LabelSelectorBuilder builder;
    public N and() {
      return (N) KubeletConfigSpecFluentImpl.this.withMachineConfigPoolSelector(builder.build());
    }
    public N endMachineConfigPoolSelector() {
      return and();
    }
    
  }
  
}
